@@ -1149,7 +1149,7 @@ class mediafile(object):
 
         self.uploadname=self.englishname+' '+str(self.year)
         self.small_descr=self.douban_dict['names']['chinesename'].strip()
-
+        
         
         medianame=self.uploadname
         if self.pathinfo.type=='anime' or self.pathinfo.type=='tv':
@@ -1159,13 +1159,13 @@ class mediafile(object):
             medianame=self.uploadname
             if not self.isdir:
                 self.uploadname=self.uploadname+'E'+self.episodename
-                self.small_descr=self.small_descr+' | 第E'+self.episodename+'集'
+                self.small_descr=self.small_descr+' | 第'+self.episodename+'集'
             elif self.complete==1:
                 self.uploadname=self.uploadname
                 self.small_descr=self.small_descr+' | 全 '+str(self.pathinfo.max)+' 集'
             else:
                 self.uploadname=self.uploadname+'E'+str(self.pathinfo.min).zfill(2)+'-E'+str(self.pathinfo.max).zfill(2)
-                self.small_descr=self.small_descr+' | 第E'+str(self.pathinfo.min).zfill(2)+'-E'+str(self.pathinfo.max).zfill(2)+'集'
+                self.small_descr=self.small_descr+' | 第'+str(self.pathinfo.min).zfill(2)+'-'+str(self.pathinfo.max).zfill(2)+'集'
 
 
         if self.douban_dict['directors']:
